﻿package {
	
	import flash.events.Event;
	import flash.net.URLLoader;
	import flash.net.URLRequest;
	
	/**
	 * Rutetabell - Klasse
	 * 
	 * Leser inn rutetabell fra xml-fil til xml-variabel.
	 * Bruker AS attributt-syntaks (@attr=...) til å slå opp.
	 * 
	 * Interface:
	 *    Rutetabell()				Leser inn rutetabell fra xml-fil til xml-variabel
	 *    getFra():Object			Hent fra-data som skal legges i combobox
	 *    getTil():Object			Hent til-data som skal legges i combobox
	 *    getAvstand(fra: String, til: String): Number    Slår opp riktig avstand
	 * 	  getLoader():URLLoader		Trenger for å henge på lytter som venter på Event.COMPLETE...
	 * 
	 * @author H-P Ulven
	 * @version 12.03.12
	 */
	public class Rutetabell {
		
		private var rutetabell: XML = null;
		
		private var xmlURL:URLRequest = new URLRequest("rutetabell.xml");
		private var xmlLoader:URLLoader = new URLLoader(xmlURL);
		
		/* Konstruktør leser inn fil til variabel rutetabell */
		public function Rutetabell():void {
			xmlLoader.addEventListener(Event.COMPLETE, rutetabellFerdig);			
		}//constructor
		
		private function rutetabellFerdig(evt:Event):void {
			rutetabell = XML(evt.target.data);
		}//rutetabellFerdig()		
		
		/* Oppslagsfunksjonen */
		public function getAvstand(fra: String, til: String): Number {
			return Number( rutetabell.avstand.(@fra == fra).verdi.(@til == til) );
		}//getAvstand(fra, til)
		
		/* Lager array med objekter {label:franavn, data: nr} til kombobox fraCb */
		public function getFraNavn():Array {
			var navn: Array = new Array();
			var o: Object = null;
			for(var i: int = 0;i<rutetabell.avstand.length();i++) {
				o=new Object();
				o.label=rutetabell.avstand[i].@fra; 	//label settes
				o.data=i;								//data settes (kan være tom)
				navn.push(o);							//legger i array
			}//for
			return navn;								//returnerer array
		}//getFraNavn
		
		/* Lager objekter til kombobox tilCb */
		public function getTilNavn():Array {
			var navn: Array = new Array();
			var o: Object=null;
			for(var i: int = 0;i<rutetabell.avstand[0].verdi.length();i++) {
				o=new Object();
				o.label=rutetabell.avstand[0].verdi[i].@til; 
				o.data=i;
				navn.push(o);
			}//for
			return navn;			
		}//getTilNavn()
		
		/* Returnerer loader slik at brukere av klassen kan henge på lytter
		   for å sikre at filen er lastet før forsøk på bruk av klassen
		*/
		public function getLoader(): URLLoader { return xmlLoader;}
		
		 /* Debug function: Lister ut innhold  i rutetabell */
		public function debug(): void {
			var fra: String;
			var til: String;
			trace("rutetabell.debug():");
			for (var i:int = 0; i < rutetabell.avstand.length(); i++) {
				fra = rutetabell.avstand[i].@fra;
				trace("fra: " + fra);
				for (var j:int=0; j< rutetabell.avstand[i].verdi.length();j++) {
					til = rutetabell.avstand[i].verdi[j].@til;
					trace("til: " + til);
					trace("avstand: " + rutetabell.avstand.(@fra == fra).verdi.(@til == til));
				}//for j
			}//for i
		}//debug()
	}//class
	
}//package